#
# spec file for package rmpc
#
# Copyright (c) 2024 mantarimay
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without test
Name:           rmpc
Version:        0.6.0
Release:        bp160.1.7
Summary:        Rusty Music Player Client for MPD
License:        BSD-3-Clause
URL:            https://github.com/mierak/rmpc
Source0:        %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  cargo-packaging
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  rust >= 1.74
Recommends:     mpd
Recommends:     yt-dlp

%description
RMPC is a beautiful, modern and configurable terminal based Music Player
Daemon client with album art support. It is heavily inspired by ncmpcpp
and ranger/lf file managers.

%prep
%autosetup -a1 -p1

%build
%{cargo_build}

%install
install -Dm755 target/release/%{name} -t %{buildroot}%{_bindir}
install -Dm644 target/man/%{name}.1 -t %{buildroot}%{_mandir}/man1
install -Dm644 target/completions/%{name}.bash -t \
    %{buildroot}%{_datadir}/bash-completion/completions
install -Dm644 target/completions/%{name}.fish -t \
    %{buildroot}%{_datadir}/fish/vendor_completions.d
install -Dm644 target/completions/_%{name} -t \
    %{buildroot}%{_datadir}/zsh/site-functions

%if %{with test}
%check
%{cargo_test} -- \
    --skip=config::utils::tests::home_dir_not_present::_yes_yes_expects
%endif

%files
%license LICEN*
%doc README* CHANGELOG.md
%{_bindir}/%{name}
%{_mandir}/man*/%{name}.*
%{_datadir}/bash-completion/completions
%{_datadir}/fish
%{_datadir}/zsh

%changelog
* Mon Oct 28 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.6.0
  + Added
  - Arrow keys as secondary navigation keybinds alongside hjkl
  - Support for basic control with mouse.
  - Scrolloff option to keep some context the various
    lists/tables
  - Update/rescan CLI commands to refresh MPD's database
  - Support MPD password via config, env vars and CLI
  - ShowInfo action to queue pane. Displays metadata of the song
    under cursor in a modal popup.
  - ShowCurrentSongInfo global action. Displays metadata of the
    song currently playing song in a modal popup.
  + Changed
  - Removed left/right arrows as default keybinds for
    next/previous tab.
  - Filtering is now incremental
  - Up/Down actions do not wrap around anymore.
  - Allow seeking while paused
  + Fixed
  - Rmpc now logs warnings and errors in CLI mode to stderr
  - try to clean up after yt-dlp in case it fails
  - Album art not clearing properly after direct tab switch
  - Events being duplicated when panes were present in multiple
    tabs
  - Ueberzugpp redrawing album art while in an inactive TMUX
    window/session
  - Fix improper scrollbar rendering with some symbols being empty
  - Removed duplicated tags in metadata view of a song
* Fri Sep 27 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.5.0
  + Fixed
  - allow negative one in status.volume
  - Do not query album art when it is disabled
  - browser column zero width, make docs wider
  - skip unnecessary album art work and fix some overdraws when
    changing screens
  - always print CARGO_PKG_VERSION
  - improve logging of mpd parse failures
* Wed Aug 28 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Change license from MIT to BSD-3-Clause
* Mon Aug 26 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- skip config::utils::tests::home_dir_not_present::_yes_yes_expects
  on test unit, its make build failed on Factory
* Fri Jun 21 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Initial package
